==> nbproject_test-0.4.0.tar.gz: nbproject_test-0.4.0/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🔥 Remove preprocessing | [12](https://github.com/laminlabs/nbproject-test/pull/12) | [falexwolf](https://github.com/falexwolf) | 2022-11-03 | 0.4.0
✨ Log time to execute notebooks | [11](https://github.com/laminlabs/nbproject-test/pull/11) | [Koncopd](https://github.com/Koncopd) | 2022-10-22 | 0.3.2
🐛 Ignore dates | [10](https://github.com/laminlabs/nbproject-test/pull/10) | [falexwolf](https://github.com/falexwolf) | 2022-10-18 |
🚸 Add a preprocessing function that strips prefixes | [commit](https://github.com/laminlabs/nbproject-test/commit/d17e47088aec72acffcf29786369c9f2d041e9b6) | [falexwolf](https://github.com/falexwolf) | 2022-10-08 | 0.3.1
🚸 Add a preprocessing function that strips prefixes | [8](https://github.com/laminlabs/nbproject-test/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-10-05 | 0.3.0
🐛 Fix the error in the last PR | [7](https://github.com/laminlabs/nbproject-test/pull/7) | [Koncopd](https://github.com/Koncopd) | 2022-09-06 | 0.2.2
🎨 Allow two level markdown files | [6](https://github.com/laminlabs/nbproject-test/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-06 | 0.2.1
✨ Write consecutive cell numbers | [5](https://github.com/laminlabs/nbproject-test/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-29 | 0.2.0
✨ Allows to execute a single notebook, adds tests | [3](https://github.com/laminlabs/nbproject-test/pull/3) | [Koncopd](https://github.com/Koncopd) | 2022-07-23 |
♻️ Small refactoring | [2](https://github.com/laminlabs/nbproject-test/pull/2) | [Koncopd](https://github.com/Koncopd) | 2022-07-11 |
🚚 Add code from nbproject repo | [1](https://github.com/laminlabs/nbproject-test/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-11 | 0.1.0

==> nbproject_test-0.4.1.tar.gz: nbproject_test-0.4.1/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🔊 Improve logging | [15](https://github.com/laminlabs/nbproject-test/pull/15) | [Koncopd](https://github.com/Koncopd) | 2022-11-27 | 0.4.1
🔥 Remove preprocessing | [12](https://github.com/laminlabs/nbproject-test/pull/12) | [falexwolf](https://github.com/falexwolf) | 2022-11-03 | 0.4.0
✨ Log time to execute notebooks | [11](https://github.com/laminlabs/nbproject-test/pull/11) | [Koncopd](https://github.com/Koncopd) | 2022-10-22 | 0.3.2
🐛 Ignore dates | [10](https://github.com/laminlabs/nbproject-test/pull/10) | [falexwolf](https://github.com/falexwolf) | 2022-10-18 |
🚸 Add a preprocessing function that strips prefixes | [commit](https://github.com/laminlabs/nbproject-test/commit/d17e47088aec72acffcf29786369c9f2d041e9b6) | [falexwolf](https://github.com/falexwolf) | 2022-10-08 | 0.3.1
🚸 Add a preprocessing function that strips prefixes | [8](https://github.com/laminlabs/nbproject-test/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-10-05 | 0.3.0
🐛 Fix the error in the last PR | [7](https://github.com/laminlabs/nbproject-test/pull/7) | [Koncopd](https://github.com/Koncopd) | 2022-09-06 | 0.2.2
🎨 Allow two level markdown files | [6](https://github.com/laminlabs/nbproject-test/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-06 | 0.2.1
✨ Write consecutive cell numbers | [5](https://github.com/laminlabs/nbproject-test/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-29 | 0.2.0
✨ Allows to execute a single notebook, adds tests | [3](https://github.com/laminlabs/nbproject-test/pull/3) | [Koncopd](https://github.com/Koncopd) | 2022-07-23 |
♻️ Small refactoring | [2](https://github.com/laminlabs/nbproject-test/pull/2) | [Koncopd](https://github.com/Koncopd) | 2022-07-11 |
🚚 Add code from nbproject repo | [1](https://github.com/laminlabs/nbproject-test/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-11 | 0.1.0
